//
//  FlybitsCoreConcierge.h
//  FlybitsCoreConcierge
//
//  Created by Homer Zuo on 2021-02-08.
//

#import <Foundation/Foundation.h>

//! Project version number for FlybitsCoreConcierge.
FOUNDATION_EXPORT double FlybitsCoreConciergeVersionNumber;

//! Project version string for FlybitsCoreConcierge.
FOUNDATION_EXPORT const unsigned char FlybitsCoreConciergeVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <FlybitsCoreConcierge/PublicHeader.h>


